# Interchange

Interchange is a data type and interchange format library.
It has been primarily developed for the py2neo project.


## `interchange.collections`

TODO


## `interchange.math`

TODO


## `interchange.packstream`

TODO


## `interchange.space`

TODO


## `interchange.text`

TODO


## `interchange.time`

TODO
